﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Logging;
using Performance.DtoModels;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Performance.Api
{
    public class ExceptionsFilter : IAsyncExceptionFilter
    {
        private readonly ILoggerFactory loggerFactory;

        public ExceptionsFilter(ILoggerFactory loggerFactory)
        {
            this.loggerFactory = loggerFactory;
        }
        public Task OnExceptionAsync(ExceptionContext context)
        {
            var logger = loggerFactory.CreateLogger<ExceptionsFilter>();
            logger.LogError($"接口异常:{context.Exception.ToString()}");
            if (context.Exception is PerformanceException)
            {
                context.Result = new ObjectResult(new ApiResponse(ResponseType.Fail, context.Exception.Message));
            }
            else
            {
                var response = new ApiResponse(ResponseType.Error, "接口内部异常", context.Exception.Message);
                context.Result = new ObjectResult(response);
            }
            return Task.CompletedTask;
        }
    }
}
